aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--test/unit/core.js9
1 files changed, 6 insertions, 3 deletions
diff --git a/test/unit/core.js b/test/unit/core.js
index a510c6b22..e45e493e0 100644
--- a/test/unit/core.js
+++ b/test/unit/core.js
@@ -1429,11 +1429,14 @@ QUnit.test( "jQuery.parseXML", function( assert ) {
}
} );
-// Support: IE 11+
+// Support: IE 11+, Edge 12 - 18 only
// IE throws an error when parsing invalid XML instead of reporting the error
// in a `parsererror` element, skip the test there.
QUnit[
- document.documentMode ? "skip" : "test"
+ document.documentMode || /edge\//i.test( navigator.userAgent ) ?
+ "skip" :
+ "test"
]( "jQuery.parseXML - error reporting", function( assert ) {
assert.expect( 2 );
@@ -1429,11 +1429,14 @@ QUnit.test( "jQuery.parseXML", function( assert ) {
// IE throws an error when parsing invalid XML instead of reporting the error
-// in a `parsererror` element, skip the test there.
+// in a `parsererror` element, IE & Legacy Edge don't report errors in a parsererror
+// element; skip the test there.
QUnit[